<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Avslutt programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt + N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Vis hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt + H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Tilbake</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Neste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>Om …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt + B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>View Log</source>
        <translation>Vis logg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="259"/>
        <location filename="../mainwindow.cpp" line="505"/>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Select ISO</source>
        <translation>Velg ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Velg USB-enhet for målet&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Velg ISO-fil&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>Advanced Options</source>
        <translation>Avanserte innstillinger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Opprett ext4-filsystem selv om det allerede finnes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Lagre original oppstartsmappe ved oppdatering av live-USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Bruk GPT-partisjonering istedenfor MS DOS</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>GPT partitioning</source>
        <translation>GPT-partisjonering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Oppdater (kun eksisterende live-USB)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Ikke erstatt syslinux-filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="361"/>
        <source>Keep syslinux files</source>
        <translation>Behold syslinux-filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorer sjekk av USB/flyttbar enhet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Temporarily disable automounting</source>
        <translation>Slå midlertidig av automontering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Velg pmbr_boot_disk-flagget (vil ikke starte via UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Ikke monter ISO-filer med fuseiso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>ESP (UEFI)-partisjonens størrelse:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="438"/>
        <source>Verbosity (less to more):</source>
        <translation>Tilbakemeldinger (mer eller mindre detaljerte):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>vfat</source>
        <translation>VFAT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>Make separate data partition (percent)</source>
        <translation>Opprett separat datapartisjon (prosent)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Format</source>
        <translation>Formater</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Refresh drive list</source>
        <translation>Oppdater liste over lagringsenheter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Show advanced options</source>
        <translation>Vis avanserte alternativer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="567"/>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="582"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation>Full funksjonalitet – skri&amp;vbar live-USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Ikke-skrivbar, kan ikke lagre varige data</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="595"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation>Avbildnings&amp;modus – ikke-skrivbar live-USB (dd)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Bruk avbildningsmodus (dd) for andre distribusjoner enn antiX/MX.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <source>Options</source>
        <translation>Alternativer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>Percent of USB-device to use:</source>
        <translation>Bruk denne prosentandelen av USB-enheten:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="702"/>
        <source>Label ext partition:</source>
        <translation>Ext-partisjonens volumnavn:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Ikke kjør kommandoer som påvirker USB-enheten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Dry run (no change to system)</source>
        <translation>Prøvekjøring (ingen endringer)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>klon fra en montert live-USB eller ISO-fil.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Clone an existing live system</source>
        <translation>Klon fra et eksisterende system</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Oppstart fra kryptert partisjon – vil spørre etter adgangsfrase ved første oppstart</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Encrypt</source>
        <translation>Kryptering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="780"/>
        <source>Clone running live system</source>
        <translation>Klon kjørende live-system</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="75"/>
        <source>Confirmation</source>
        <translation>Bekreft</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="76"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation>Målenheten %1 er større enn %2 GB. Vil du fortsette?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="116"/>
        <location filename="../mainwindow.cpp" line="317"/>
        <location filename="../mainwindow.cpp" line="452"/>
        <source>Failure</source>
        <translation>Mislykket</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Kilde og mål er på samme enhet – velg om igjen.</translation>
    </message>
    <message>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the the process is completed</source>
        <translation type="vanished">Skriver %1 med «dd»-kommandoen til /dev/%2,

Vennligst vent til prosessen fullføres</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="152"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the process is completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Success</source>
        <translation>Vellykket</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>LiveUSB creation successful!</source>
        <translation>LiveUSB er nå opprettet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Det oppstod en feil under oppretting av live-USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Please select a USB device to write to</source>
        <translation>Velg en USB-enhet som skal skrives til</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Disse handlingene vil slette alle data på

</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>Do you wish to continue?</source>
        <translation>Vil du fortsette?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Dette programmet kan opprette en live-USB fra en ISO-fil, en annen live-USB, en live-CD/-DVD eller et kjørende live-system.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Opphavsrett (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>%1 License</source>
        <translation>Lisens for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>%1 Help</source>
        <translation>Hjelpetekst for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Velg en ISO-fil som skal skrives til USB-enheten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation>ISO-filer (*.iso);;Alle filer(*.*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Select Source Directory</source>
        <translation>Velg kildemappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Fant ikke fila %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Hide advanced options</source>
        <translation>Skjul avanserte alternativer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Select Source</source>
        <translation>Velg kilde</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <location filename="../mainwindow.cpp" line="524"/>
        <source>Select ISO file</source>
        <translation>Velg ISO-fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>clone</source>
        <translation>klon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Could not find a log file at: </source>
        <translation>Fant ikke loggen på:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Endringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Dette programmet kan opprette en live-USB fra en ISO-fil, en annen live-USB, en live-CD/-DVD eller et kjørende live-system.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>filename</source>
        <translation>filnavn</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Name of .iso file to open</source>
        <translation>Navnet til .iso-fila som skal åpnes</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>[filename]</source>
        <translation>[filnavn]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du er innlogget som root. Vennligst logg ut, og logg inn igjen som en vanlig bruker for å bruke dette programmet.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="103"/>
        <source>version:</source>
        <translation>versjon:</translation>
    </message>
</context>
</TS>
